mi_malloc

Function mi_malloc 

pub unsafe extern "C" fn mi_malloc(size: usize) -> *mut c_void
Allocate size uninitialized bytes.

Returns a pointer to the allocated memory or null if out of memory. The pointer will still be unique if size is 0.