pub unsafe extern "C" fn mi_malloc_aligned(
size: usize,
align: usize,
) -> *mut c_voidExpand description
Allocate size uninitialized bytes with an alignment of align.
Returns a pointer to the allocated memory or null if out of memory. The pointer will still
be unique if size is 0.`