pub unsafe extern "C" fn mi_zalloc_aligned(
size: usize,
align: usize,
) -> *mut c_voidExpand description
Allocate size zeroed bytes with an alignment of align, initialized to zero.
Returns a pointer to the allocated memory or null if out of memory. The pointer will still
be unique if size is 0.`